get.chrom.length: Get Chromosome Length

View source: R/get.chrom.length.R

get.chrom.lengthR Documentation

Get Chromosome Length

Description

Retrieves chromosome size data for the 22 autosomes and X and Y chromosomes of the human GRCh38 (hg38) genome assembly using UCSC chromosome information accessed through the circlize package.

Usage

get.chrom.length(genome.assembly)

Arguments

genome.assembly

Character string specifying the genome assembly. Currently, only "Human_GRCh38" is supported.

Details

The function retrieves chromosome size information for the GRCh38 (hg38) genome assembly using circlize::read.chromInfo(). The returned data are restricted to the 22 autosomes and X and Y chromosomes and are ordered from chromosome 1 through chromosome 22, followed by X and Y. Chromosome identifiers are returned without the "chr" prefix.

Value

A data.frame with 24 rows and the following columns:

chrom

Chromosome identifier (1-22, X, or Y).

size

Chromosome size in base pairs.

Author(s)

Abdelrahman Elsayed abdelrahman.elsayed@stjude.org

References

Cao, X., Elsayed, A. H., & Pounds, S. B. (2023). Statistical Methods Inspired by Challenges in Pediatric Cancer Multi-omics.

See Also

read.chromInfo

Examples

# Retrieve chromosome size data for the GRCh38 genome assembly
hg38.chrom.size <- get.chrom.length("Human_GRCh38")


GRIN2 documentation built on Aug. 22, 2026, 5:09 p.m.