hg38_chrom_size: Chromosome Length Data (GRCh38)

hg38_chrom_sizeR Documentation

Chromosome Length Data (GRCh38)

Description

This dataset contains chromosome lengths, in base pairs, for the 22 autosomes and the X and Y chromosomes of the human GRCh38 (hg38) genome assembly. The data were retrieved from UCSC chromosome information using the get.chrom.length function with "Human_GRCh38" as the selected genome assembly.

Usage

hg38_chrom_size

Format

hg38_chrom_size

A data frame with 24 rows and 2 columns:

chrom

Chromosome identifier (1-22, X, or Y).

size

Chromosome length in base pairs.

UCSC chromosome information for the GRCh38 (hg38) genome assembly, retrieved using get.chrom.length("Human_GRCh38") through circlize::read.chromInfo().


GRIN2 documentation built on Aug. 22, 2026, 5:09 p.m.