hg38_cytoband: GRCh38 Chromosome Cytobands

hg38_cytobandR Documentation

GRCh38 Chromosome Cytobands

Description

This dataset contains the genomic coordinates of cytogenetic bands (cytobands) for the 22 autosomes and the X and Y chromosomes of the human GRCh38 (hg38) genome assembly. The dataset is primarily used by lsn.transcripts.plot to provide chromosome cytoband information for regional lesion and transcript visualization.

Usage

hg38_cytoband

Format

hg38_cytoband

A data frame with 1,549 rows and 5 columns:

chrom

Chromosome identifier (1-22, X, or Y).

chromStart

Start coordinate of the cytoband in base pairs, using the UCSC 0-based coordinate convention.

chromEnd

End coordinate of the cytoband in base pairs, using the UCSC end-exclusive coordinate convention.

name

Cytoband name (e.g., p11.1 or q22.3).

gieStain

Giemsa staining classification used for cytogenetic visualization (e.g., gneg, gpos, acen).

UCSC Genome Browser cytoband data for the GRCh38 (hg38) genome assembly: https://hgdownload.soe.ucsc.edu/goldenPath/hg38/database/

See Also

lsn.transcripts.plot


GRIN2 documentation built on Aug. 22, 2026, 5:09 p.m.