lesion_data: Example T-ALL Lesion Dataset

lesion_dataR Documentation

Example T-ALL Lesion Dataset

Description

This dataset contains genomic lesions identified in 265 patients with newly diagnosed T-cell acute lymphoblastic leukemia (T-ALL), as reported by Liu, Yu, et al. (2017). The dataset includes copy-number alterations, single nucleotide variants, and structural rearrangements and is provided as an example lesion dataset for GRIN2 analyses.

Usage

lesion_data

Format

lesion_data

A data frame with 6,861 rows and 5 columns:

ID

Patient identifier for the individual affected by the lesion.

chrom

Chromosome identifier on which the lesion is located.

loc.start

Lesion start position in base pairs (GRCh38).

loc.end

Lesion end position in base pairs (GRCh38).

lsn.type

Type of genomic lesion.

Details

The original genomic coordinates were based on the GRCh37 (hg19) human genome assembly. Coordinates were converted to the GRCh38 (hg38) genome assembly using the UCSC LiftOver tool before inclusion in GRIN2. All genomic coordinates in this dataset therefore correspond to GRCh38.

Adapted from the supplementary data of Liu, Yu, et al. (2017), Nature Genetics. Original GRCh37 genomic coordinates were converted to GRCh38 using the UCSC LiftOver tool.

Liu, Y., et al. (2017). The genomic landscape of pediatric and young adult T-lineage acute lymphoblastic leukemia. Nature Genetics.

UCSC LiftOver: https://genome.ucsc.edu/cgi-bin/hgLiftOver


GRIN2 documentation built on Aug. 22, 2026, 5:09 p.m.