View source: R/compute.gw.coordinates.R
| compute.gw.coordinates | R Documentation |
Computes and adds continuous genome-wide plotting coordinates to chromosome, gene, and lesion data for use in genome-wide lesion plots.
compute.gw.coordinates(grin.res, scl = 1000000)
grin.res |
GRIN results, typically the output of the |
scl |
Numeric; number of base pairs represented by one plotting unit. Default is 1,000,000, so genome-wide coordinates are expressed in megabase units. |
This function adds x.start and x.end coordinates that place genomic
positions from all chromosomes on a continuous genome-wide plotting axis.
The original chromosome-specific genomic coordinates in loc.start and
loc.end are retained unchanged.
Chromosome lengths and genomic positions are scaled according to scl.
Cumulative chromosome lengths are then used to offset the coordinates of
each chromosome so that chromosomes are positioned consecutively along a
continuous genome-wide axis.
Specifically:
The chromosome size table is updated with x.start and x.end
columns defining the genome-wide plotting boundaries of each chromosome.
Gene coordinates in gene.data and gene.hits are updated with
corresponding x.start and x.end plotting coordinates.
Lesion coordinates in lsn.data are updated with corresponding
x.start and x.end plotting coordinates.
A GRIN results list containing the original components with genome-wide plotting coordinates added to the relevant chromosome, gene, and lesion data:
GRIN gene-level summary statistics with added x.start
and x.end plotting coordinates.
Unchanged gene-lesion overlap data.
Lesion data with added x.start and x.end plotting
coordinates.
Gene annotation data with added x.start and x.end
plotting coordinates.
Chromosome size table with added x.start and x.end
coordinates defining chromosome positions on the genome-wide plotting
axis.
Unchanged chromosome index used to identify chromosome-specific rows in the gene data.
Unchanged chromosome index used to identify chromosome-specific rows in the lesion data.
Abdelrahman Elsayed abdelrahman.elsayed@stjude.org and Stanley Pounds stanley.pounds@stjude.org
Pounds, S., et al. (2013). A genomic random interval model for statistical analysis of genomic lesion data.
Cao, X., Elsayed, A. H., & Pounds, S. B. (2023). Statistical Methods Inspired by Challenges in Pediatric Cancer Multi-omics.
grin.stats,
genomewide.lsn.plot
data(lesion_data)
data(hg38_gene_annotation)
data(hg38_chrom_size)
# Run GRIN analysis
grin.results <- grin.stats(lesion_data,
hg38_gene_annotation,
hg38_chrom_size)
# Add genome-wide coordinates for plotting
genome.coord <- compute.gw.coordinates(grin.results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.