View source: R/get.chrom.length.R
| get.chrom.length | R Documentation |
Retrieves chromosome size data for the 22 autosomes and X and Y chromosomes
of the human GRCh38 (hg38) genome assembly using UCSC chromosome information
accessed through the circlize package.
get.chrom.length(genome.assembly)
genome.assembly |
Character string specifying the genome assembly.
Currently, only |
The function retrieves chromosome size information for the GRCh38 (hg38)
genome assembly using circlize::read.chromInfo(). The returned data are
restricted to the 22 autosomes and X and Y chromosomes and are ordered from
chromosome 1 through chromosome 22, followed by X and Y. Chromosome
identifiers are returned without the "chr" prefix.
A data.frame with 24 rows and the following columns:
Chromosome identifier (1-22, X, or Y).
Chromosome size in base pairs.
Abdelrahman Elsayed abdelrahman.elsayed@stjude.org
Cao, X., Elsayed, A. H., & Pounds, S. B. (2023). Statistical Methods Inspired by Challenges in Pediatric Cancer Multi-omics.
read.chromInfo
# Retrieve chromosome size data for the GRCh38 genome assembly
hg38.chrom.size <- get.chrom.length("Human_GRCh38")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.