Learn R Programming

GRIN2 (version 2.0.0)

get.ensembl.annotation: Get Ensembl Gene and Regulatory Features Annotation Data

Description

Retrieves gene and regulatory feature annotation data from the Ensembl BioMart database for the Human GRCh38 (hg38) genome assembly using the biomaRt package.

Usage

get.ensembl.annotation(genome.assembly)

Value

A list with three components:

gene.annotation

Data frame of gene-level annotation.

reg.annotation.predicted

Data frame of predicted regulatory features.

reg.annotation.validated

Data frame of validated regulatory features (FANTOM5).

Arguments

genome.assembly

Character string. Currently, only "Human_GRCh38" is supported.

Author

Abdelrahman Elsayed abdelrahman.elsayed@stjude.org and Stanley Pounds stanley.pounds@stjude.org

Details

This function retrieves:

  • Gene annotation: Ensembl ID, chromosome, start/end positions, gene name, description, biotype, strand, and cytogenetic band.

  • Predicted regulatory features: Promoters, enhancers, CTCF binding sites, etc., from the Ensembl regulatory build.

  • Validated regulatory features: Experimentally confirmed enhancers and TSSs from the FANTOM5 project.

References

Cao, X., Elsayed, A. H., & Pounds, S. B. (2023). Statistical Methods Inspired by Challenges in Pediatric Cancer Multi-omics.

Zerbino, Daniel R., et al. (2015). The ensembl regulatory build.

Kinsella, Rhoda J., et al. (2011). Ensembl BioMarts: a hub for data retrieval across taxonomic space.

See Also

useEnsembl, getBM

Examples

Run this code
# \donttest{
hg38.ann <- get.ensembl.annotation("Human_GRCh38")
# gene level annotations:
hg38.genes <- hg38.ann$gene.annotation
# regulatory sequences from the ensembl genome build:
hg38.reg.pred <- hg38.ann$reg.annotation.predicted
# regulatory sequences from the FANTOM5 project:
hg38.reg.val <- hg38.ann$reg.annotation.validated
# }

Run the code above in your browser using DataLab