| hg38_chrom_size | R Documentation |
This dataset contains chromosome lengths, in base pairs, for the 22 autosomes
and the X and Y chromosomes of the human GRCh38 (hg38) genome assembly.
The data were retrieved from UCSC chromosome information using the
get.chrom.length function with "Human_GRCh38" as the selected genome
assembly.
hg38_chrom_size
hg38_chrom_sizeA data frame with 24 rows and 2 columns:
Chromosome identifier (1-22, X, or Y).
Chromosome length in base pairs.
UCSC chromosome information for the GRCh38 (hg38) genome assembly, retrieved
using get.chrom.length("Human_GRCh38") through
circlize::read.chromInfo().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.