| hg38_cytoband | R Documentation |
This dataset contains the genomic coordinates of cytogenetic bands
(cytobands) for the 22 autosomes and the X and Y chromosomes of the human
GRCh38 (hg38) genome assembly. The dataset is primarily used by
lsn.transcripts.plot to provide chromosome cytoband information for
regional lesion and transcript visualization.
hg38_cytoband
hg38_cytobandA data frame with 1,549 rows and 5 columns:
Chromosome identifier (1-22, X, or Y).
Start coordinate of the cytoband in base pairs, using the UCSC 0-based coordinate convention.
End coordinate of the cytoband in base pairs, using the UCSC end-exclusive coordinate convention.
Cytoband name (e.g., p11.1 or q22.3).
Giemsa staining classification used for cytogenetic visualization (e.g., gneg, gpos, acen).
UCSC Genome Browser cytoband data for the GRCh38 (hg38) genome assembly: https://hgdownload.soe.ucsc.edu/goldenPath/hg38/database/
lsn.transcripts.plot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.