Learn R Programming

GRIN2 (version 2.0.0)

hg38_cytoband: GRCh38 Chromosome Cytobands

Description

This dataset contains the start and end positions (in base pairs) of cytogenetic bands (cytobands) for all 22 autosomes, as well as the X and Y chromosomes, based on the Human GRCh38 (hg38) genome assembly.

Usage

hg38_cytoband

Arguments

Format

hg38_cytoband

A data frame with 1,549 rows and 5 columns:

chrom

Chromosome name (1:22, X, Y).

chromStart

Start position of the cytoband in base pairs.

chromEnd

End position of the cytoband in base pairs.

name

Name of the cytoband (e.g., p11.1, q22.3).

gieStain

Staining pattern (e.g., gpos, gneg, acen) used for cytogenetic visualization.