This dataset contains the start and end positions (in base pairs) of cytogenetic bands (cytobands) for all 22 autosomes, as well as the X and Y chromosomes, based on the Human GRCh38 (hg38) genome assembly.
hg38_cytobandhg38_cytoband
A data frame with 1,549 rows and 5 columns:
Chromosome name (1:22, X, Y).
Start position of the cytoband in base pairs.
End position of the cytoband in base pairs.
Name of the cytoband (e.g., p11.1, q22.3).
Staining pattern (e.g., gpos, gneg, acen) used for cytogenetic visualization.