| lesion_data | R Documentation |
This dataset contains genomic lesions identified in 265 patients with newly diagnosed T-cell acute lymphoblastic leukemia (T-ALL), as reported by Liu, Yu, et al. (2017). The dataset includes copy-number alterations, single nucleotide variants, and structural rearrangements and is provided as an example lesion dataset for GRIN2 analyses.
lesion_data
lesion_dataA data frame with 6,861 rows and 5 columns:
Patient identifier for the individual affected by the lesion.
Chromosome identifier on which the lesion is located.
Lesion start position in base pairs (GRCh38).
Lesion end position in base pairs (GRCh38).
Type of genomic lesion.
The original genomic coordinates were based on the GRCh37 (hg19) human genome assembly. Coordinates were converted to the GRCh38 (hg38) genome assembly using the UCSC LiftOver tool before inclusion in GRIN2. All genomic coordinates in this dataset therefore correspond to GRCh38.
Adapted from the supplementary data of Liu, Yu, et al. (2017), Nature Genetics. Original GRCh37 genomic coordinates were converted to GRCh38 using the UCSC LiftOver tool.
Liu, Y., et al. (2017). The genomic landscape of pediatric and young adult T-lineage acute lymphoblastic leukemia. Nature Genetics.
UCSC LiftOver: https://genome.ucsc.edu/cgi-bin/hgLiftOver
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.