data(lesion_data)
# Automatically assign oncoprint proportions based on average lesion size:
onco.props <- onco.print.props(lesion_data)
# Alternatively, manually specify the oncoprint fill proportions for each lesion type:
onco.props <- onco.print.props(lesion_data,
hgt = c("gain" = 4, "loss" = 3, "mutation" = 2, "fusion" = 1))
Run the code above in your browser using DataLab