View source: R/order.index.gene.data.R
| order.index.gene.data | R Documentation |
Orders gene annotation data by chromosome and genomic coordinates and creates an index identifying the rows corresponding to each chromosome. This helper function is used to prepare gene annotation data for downstream GRIN overlap analyses.
order.index.gene.data(gene.data)
gene.data |
A
|
Genes are ordered by chromosome, start position, and end position.
Consecutive rows belonging to the same chromosome are represented by a
single entry in gene.index, which records the first and last corresponding
row in the ordered gene annotation data.
A gene.row column is added to the ordered gene annotation data and is used
internally by downstream GRIN functions.
A list with two components:
The input gene annotation data ordered by chromosome,
loc.start, and loc.end, with an added gene.row column.
A data.frame with three columns: chrom,
row.start, and row.end, identifying the range of rows corresponding
to each chromosome in the ordered gene annotation data.
Abdelrahman Elsayed abdelrahman.elsayed@stjude.org and Stanley Pounds stanley.pounds@stjude.org
Pounds, S., et al. (2013). A genomic random interval model for statistical analysis of genomic lesion data.
Cao, X., Elsayed, A. H., & Pounds, S. B. (2023). Statistical Methods Inspired by Challenges in Pediatric Cancer Multi-omics.
prep.gene.lsn.data,
get.ensembl.annotation
data(hg38_gene_annotation)
# Order gene annotation data and create chromosome-specific row indices
ordered.genes <- order.index.gene.data(hg38_gene_annotation)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.